@@ -10,7 +10,7 @@ use Net::SSLLabs::Endpoint();
 use Net::SSLLabs::StatusCodes();
 use Encode();
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub new {
     my ($class) = @_;
@@ -107,7 +107,7 @@ Net::SSLLabs - An interface to the ssllabs.com service
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =head1 SYNOPSIS
 
@@ -116,9 +116,8 @@ Check the security of your TLS services
     use Net::SSLLabs;
 
     my $labs = Net::SSLLabs->new();
-    ...
     my $host;
-    while(not $host = $lab->analyze(host => 'ssllabs.com')) {
+    while(not $host = $labs->analyze(host => 'ssllabs.com')) {
         sleep 10;
     }
     foreach my $endpoint ($host->endpoints()) {
